/*
	Replication file for Figures 1 & 2, as well as Appendix Tables A3 & A4
*/

// Set directories
	cd "C:\Users\[filename]\Replication"
	loc dir "C:\Users\[filename]\Replication"

	use `dir'/ycls_full.dta, clear

	// Combine abstain/other vote
		gen vote16_absoth = vote16_abs == 1 | vote16_oth ==1
		
	// Covariates
		tab week, gen(week_)
		loc covarlist "d_black d_asian d_raceother d_hispanic d_female x_* week_*"
		// Omitted variables
		drop x_age_bin_4 x_educ_3 x_age_bin_0 week_1
		
	// Scale Measure Indicators
		tab job_change, gen(change)
	
	// Fix Labels
		label var vote16_absoth "Abstained/Voted"
		label var vote16_dem "Democrat/Clinton"
		label var vote16_gop "Republican/Trump"
		label var change1 "Worsened by 2 units"
		label var change2 "Worsened by 1 unit"
		label var change4 "Improved by 1 unit"
		label var change5 "Improved by 2 units"
		label var job_worse "Employment Worsened"
		label var job_improve "Employment Improved"
	
	// Change in vote from 2016 to 2020 (positive = more Republican)
	foreach v in 16 20 {
		cap drop vote`v'_value
		gen vote`v'_value = 1 if vote`v'_gop == 1
		replace vote`v'_value = -1 if vote`v'_dem == 1
		replace vote`v'_value = 0 if missing(vote`v'_value)
	}
	cap drop vote_change
	gen vote_change = vote20_value - vote16_value
	
	

	eststo clear	

//------------------------------ FIGURE 1
	//Regressions for Coefplot
	// Indicators
	reg vote20_gopdem job_worse job_improve vote16_dem vote16_gop `covarlist', robust
	eststo base_dum
	
	// Scale
	reg vote20_gopdem change1 change2 change4 change5 vote16_dem vote16_gop `covarlist', robust
	eststo base_scale
	
	// Make figure
	coefplot base_dum, bylabel("(1) Indicator Measure") mc(black) ciopts(color(black) lw(medthick))  ///
		|| base_scale, bylabel("(2) Scale Measure") mc(black) ciopts(color(black) lw(medthick))  ///
		||, drop(_cons `covarlist' vote16_dem vote16_gop) ///
		ms(c) msize(medlarge) ylabel(,labsize(medsmall)) ///
		xline(0, lc(black)) ///
		subtitle(, bcolor(black) color(white) size(medsmall)) ///
		byopts(row(1) title("Figure 1. Effect of Change in Employment on 2020 Republican Vote Intention", /// 
			size(medsmall) pos(11)) legend(off) ///
			note("Points denote coefficients from OLS regression. Omitted covariates: HHI, age, education, region, race, gender, week indictors." ///
				"2016 vote indicators are omitted in (1) and (2). Republican Vote Intention = -1 if Democrat, 0 if Abstain/Other, and 1 if Republican.", size(vsmall))) ///
		xtitle("", size(vsmall)) norecycle xscale(range(-.25 .25)) ///
		headings(job_worse = "{bf: Indicators}" change1 = "{bf: Scale}" ///
			i_job_worse_d = "{bf: 2016 Vote X Indicators}" i_change1_d = "{bf: 2016 Vote X Scale}", labsize(medsmall))

	graph export `dir'/figure_1.png, as(png) replace
	

////------------------------------ FIGURE 2

// Regerssions
	// A. Industry
	encode jlv_industry, gen(industry)
	xtreg vote20_gopdem job_worse job_improve vote16_dem vote16_gop `covarlist',  vce(robust) fe i(industry) 
	eststo industry_dum
	outreg2 using `dir'/table_A4.xls, replace addtext(Covariates, Yes) ctitle(Industry FE) dec(3)

	// B. State and Industry
	replace d_state = "Other" if strpos(d_state, "reside") != 0 
	replace d_state = "Other" if missing(d_state)
	encode d_state, gen(state_num)
	tab state_num, gen(state_)
	drop state_num

	xtreg vote20_gopdem job_worse job_improve vote16_dem vote16_gop `covarlist' state_*,  vce(robust) fe i(industry) 
	eststo industrystate_dum
	outreg2 using `dir'/table_A4.xls, append addtext(Covariates, Yes) ctitle(Industry + State FE) dec(3)
	
	// C. In LF in Jan 2020
	gen janlf = inlist(employ_past, "Working full time", "Working part time")

	reg vote20_gopdem job_worse job_improve vote16_dem vote16_gop `covarlist' if janlf == 1, robust
	eststo janlf_dum	
	outreg2 using `dir'/table_A4.xls, append addtext(Covariates, Yes) ctitle(January Labor Force) dec(3)
	
	// D. Outcome is Vote Change insetad of Republican Vote Intention
	reg vote_change job_worse job_improve `covarlist', robust
	eststo votechange_dum
	outreg2 using `dir'/table_A4.xls, append addtext(Covariates, Yes) ctitle(Vote Change) dec(3)
	
	// E. No 2016
	reg vote20_gopdem job_worse job_improve `covarlist', robust
	eststo no16_dum	
	outreg2 using `dir'/table_A4.xls, append addtext(Covariates, Yes) ctitle(No 2016 Vote Choice) dec(3)
	
	// F. Party ID instead of 2016 vote
	cap drop pid7_8 // these are all missing anyway
	label var pid7_1 "Strong Democrat"
	label var pid7_2 "Weak Democrat"
	label var pid7_3 "Lean Democrat"
	label var pid7_4 "Independent"
	label var pid7_5 "Lean Republican"
	label var pid7_6 "Weak Democrat"
	label var pid7_7 "Strong Republican"

	reg vote20_gopdem job_worse job_improve ///
		pid7_1 pid7_2 pid7_3 pid7_5 pid7_6 pid7_7 vote16_dem vote16_gop ///
		`covarlist', robust
	eststo pid_dum
	outreg2 using `dir'/table_A4.xls, append addtext(Covariates, Yes) ctitle(Party ID) dec(3)
	

// Make panels
	label var job_worse "Worsened" // For aesthetics
	label var job_improve "Improved"

	// Industry
	coefplot industry_dum, mc(black) ciopts(color(black) lw(medthick))  ///
		||, drop(_cons `covarlist' vote16_dem vote16_gop) ///
		ms(c) msize(medlarge) ylabel(,labsize(medsmall)) ///
		xline(0, lc(black)) ///
		subtitle("(A) Industry Fixed Effects", bcolor(black) color(white) size(small) box pos(12) ///
			bmargin(small) bexpand margin(small)) ///
		xtitle("", size(vsmall)) xlabel(-.2(0.05).2) ///
		saving(fig2a.gph, replace)
	graph export `dir'/figure_2a.png, as(png) replace
	
	
	// Industry and State FE
	coefplot industrystate_dum, mc(black) ciopts(color(black) lw(medthick))  ///
		||, drop(_cons `covarlist' state* vote16_dem vote16_gop) ///
		ms(c) msize(medlarge) ylabel(,labsize(medsmall)) ///
		xline(0, lc(black)) ///
		subtitle("(B) Industry and State Fixed Effects", bcolor(black) color(white) size(small) box pos(12) ///
			bmargin(small) bexpand margin(small)) ///
		xtitle("", size(vsmall)) xlabel(-.2(0.05).2) ///
		saving(fig2b.gph, replace)
	graph export `dir'/figure_2b.png, as(png) replace
	
	
	// Restricted to Jan labor force
	coefplot janlf_dum, mc(black) ciopts(color(black) lw(medthick))  ///
		||, drop(_cons `covarlist' vote16_dem vote16_gop) ///
		ms(c) msize(medlarge) ylabel(,labsize(medsmall)) ///
		xline(0, lc(black)) ///
		subtitle("(C) Those in January Labor Force", bcolor(black) color(white) size(small) box pos(12) ///
			bmargin(small) bexpand margin(small)) ///
		xtitle("", size(vsmall)) xlabel(-.2(0.05).2) ///
		saving(fig2c.gph, replace)
	graph export `dir'/figure_2c.png, as(png) replace
	
	// Outcome is vote change
	coefplot votechange_dum, mc(black) ciopts(color(black) lw(medthick))  ///
		||, drop(_cons `covarlist') ///
		ms(c) msize(medlarge) ylabel(,labsize(medsmall)) ///
		xline(0, lc(black)) ///
		subtitle("(D) Outcome: Vote Change", bcolor(black) color(white) size(small) box pos(12) ///
			bmargin(small) bexpand margin(small)) ///
		xtitle("", size(vsmall)) xlabel(-.2(0.05).2) ///
		saving(fig2d.gph, replace)
	graph export `dir'/figure_2d.png, as(png) replace
	
	// No 2016
	coefplot no16_dum, mc(black) ciopts(color(black) lw(medthick))  ///
		||, drop(_cons `covarlist') ///
		ms(c) msize(medlarge) ylabel(,labsize(medsmall)) ///
		xline(0, lc(black)) ///
		subtitle("(E) Not Controlling for 2016 Vote", bcolor(black) color(white) size(small) box pos(12) ///
			bmargin(small) bexpand margin(small)) ///
		xtitle("", size(vsmall)) xlabel(-.2(0.05).2) ///
		saving(fig2e.gph, replace)
	graph export `dir'/figure_2e.png, as(png) replace

	// Party ID instead of Vote 2016
	coefplot pid_dum, mc(black) ciopts(color(black) lw(medthick))  ///
		||, drop(_cons `covarlist' pid7_* vote16_dem vote16_gop) ///
		ms(c) msize(medlarge) ylabel(,labsize(medsmall)) ///
		xline(0, lc(black)) ///
		subtitle("(F) Controlling for Party ID", bcolor(black) color(white) size(small) box pos(12) ///
			bmargin(small) bexpand margin(small)) ///
		xtitle("", size(vsmall)) xlabel(-.2(0.05).2) ///
		saving(fig2f.gph, replace)
	graph export `dir'/figure_2f.png, as(png) replace
	

	// Combine into one figure
	graph combine fig2a.gph fig2b.gph fig2c.gph fig2d.gph fig2e.gph fig2f.gph, rows(3) 
	graph display, xsize(4) ysize(3.5)
	graph export `dir'/figure_2.png, as(png) replace
	
	
	
	
// Clean up extra files
	fs `dir'\*.txt
	foreach f in `r(files)' {
		erase `dir'/`f'
	}

	
